import os
import ffmpeg
import tkinter as tk
from tkinter import messagebox

def download_video():
    link = input("Enter YouTube Video URL:\n")
    download_location = input("Enter download location:\n")
    if link and download_location:
        try:
            os.system(f'yt-dlp -o "{download_location}/%(title)s.%(mp4)s" "{link}"')
            messagebox.showinfo("Success", "Download completed!")
        except Exception as e:
            messagebox.showerror("Error", f"An error occurred: {e}")           
    else:
        messagebox.showerror("Error", "Please provide a valid YouTube URL and download location.")

def convert_file():
    try:
        finput = input('Enter the input file path:\n')
        foutput = input('Enter the output file path:\n')
        (
            ffmpeg.input(finput)
            .output(foutput)
            .run()
        )
        messagebox.showinfo(message='Conversion Complete')
        print('Conversion Complete')
    except Exception as e:
        messagebox.showerror(message=f'{e}')


from setuptools import setup, find_packages

with open('README.md', 'r') as file:
    long_description = file.read()

setup(
    name='EToolsbyEndie',
    url='https://github.com/realendie/ETools_By_Endie',
    author='Wyatt Johnson',
    author_email='enderprooffical@gmail.com',
    license='MIT',
    license_files='LICENSE',
    version='1.0.4',
    packages=find_packages(),
    install_requires=[
        'darkdetect==0.8.0',
        'packaging==24.2',
        'yt-dlp',
        'ffmpeg',
    ],
    keywords=['python','utility','youtube','tools','downloader','video','audio','converter','mp3','mp4','youtube-dl','yt-dlp','ffmpeg'],
    short_description='ETools is an open-source python package that allows you to many things with ease, using command prompt.',
    long_description=long_description,
    long_description_content_type='text/markdown',
    entry_points={
        "console_scripts": [
            'download_video = ETools:download_video',
            'start_convert = ETools:start_convert',]
    },
)

#  python setup.py sdist bdist_wheel
#  twine upload dist/*